@@ -4,7 +4,7 @@ from urllib.error import HTTPError, URLError
 from .errors import TooManyRequests, InvalidURL, BadURL, AIOError
 
 
-__all__ = ['filter', 'parser']
+__all__ = ['dup_filter', 'parser']
 
 
 def _fetch_webpage(url: str):
@@ -15,20 +15,14 @@ def _fetch_webpage(url: str):
         if e.code == 404:
             raise InvalidURL('can not find anything with the requested url')
         if e.code == 429:
-            raise TooManyRequests('you are being ratelimited for sending too many requests')
+            raise TooManyRequests('you are being rate-limited for sending too many requests')
     except URLError:
         raise BadURL('url does not match any supported format')
     except Exception as e:
         raise AIOError(f'{e!r}')
 
 
-def filter(iterable: list, limit: int = None) -> list:
-    """
-    Restricts element repetition in iterable
-    :param int limit: number of desired elements
-    :param iterable: list or tuple of elements
-    :return: modified list (consider limit)
-    """
+def dup_filter(iterable: list, limit: int = None) -> list:
     if iterable:
         lim = limit if limit else len(iterable)
         converted = list(OrderedDict.fromkeys(iterable))
